pub fn spawn_worker() -> (ExtractionSender, JoinHandle<()>)Expand description
Spawn the extraction worker. Returns the sender half and a join handle that resolves when all in-flight work is drained.
pub fn spawn_worker() -> (ExtractionSender, JoinHandle<()>)Spawn the extraction worker. Returns the sender half and a join handle that resolves when all in-flight work is drained.